@@ -323,10 +323,7 @@
 #include "rsvg.h"
 
 /* Implemented in rsvg_internals/src/handle.rs */
-extern double rsvg_rust_handle_get_dpi_x (RsvgHandle *raw_handle);
-extern double rsvg_rust_handle_get_dpi_y (RsvgHandle *raw_handle);
-extern void rsvg_rust_handle_set_dpi_x (RsvgHandle *raw_handle, double dpi_x);
-extern void rsvg_rust_handle_set_dpi_y (RsvgHandle *raw_handle, double dpi_y);
+extern void rsvg_rust_handle_set_dpi_x_y (RsvgHandle *raw_handle, double dpi_x, double dpi_y);
 extern void rsvg_rust_handle_set_base_url (RsvgHandle *raw_handle, const char *uri);
 extern void rsvg_rust_handle_set_base_gfile (RsvgHandle *raw_handle, GFile *file);
 extern const char *rsvg_rust_handle_get_base_url (RsvgHandle *raw_handle);
@@ -335,7 +332,7 @@ extern gboolean rsvg_rust_handle_read_stream_sync (RsvgHandle *handle,
                                                    GInputStream *stream,
                                                    GCancellable *cancellable,
                                                    GError **error);
-extern void rsvg_rust_handle_write (RsvgHandle *handle, const guchar *buf, gsize count);
+extern gboolean rsvg_rust_handle_write (RsvgHandle *handle, const guchar *buf, gsize count, GError **error);
 extern gboolean rsvg_rust_handle_close (RsvgHandle *handle, GError **error);
 extern gboolean rsvg_rust_handle_has_sub (RsvgHandle *handle, const char *id);
 extern gboolean rsvg_rust_handle_render_cairo_sub (RsvgHandle *handle,
@@ -484,10 +481,6 @@ rsvg_handle_new (void)
 RsvgHandle *
 rsvg_handle_new_from_data (const guint8 *data, gsize data_len, GError **error)
 {
-    g_return_val_if_fail ((data != NULL && data_len != 0) || (data_len == 0), NULL);
-    g_return_val_if_fail (data_len <= G_MAXSSIZE, NULL);
-    g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-
     return rsvg_rust_handle_new_from_data (data, data_len, error);
 }
 
@@ -507,9 +500,6 @@ rsvg_handle_new_from_data (const guint8 *data, gsize data_len, GError **error)
 RsvgHandle *
 rsvg_handle_new_from_file (const gchar *filename, GError **error)
 {
-    g_return_val_if_fail (filename != NULL, NULL);
-    g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-
     return rsvg_rust_handle_new_from_file (filename, error);
 }
 
@@ -559,10 +549,6 @@ rsvg_handle_new_from_gfile_sync (GFile          *file,
                                  GCancellable   *cancellable,
                                  GError        **error)
 {
-    g_return_val_if_fail (G_IS_FILE (file), NULL);
-    g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), NULL);
-    g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-
     return rsvg_rust_handle_new_from_gfile_sync (file, flags, cancellable, error);
 }
 
@@ -596,11 +582,6 @@ rsvg_handle_new_from_stream_sync (GInputStream    *input_stream,
                                   GCancellable    *cancellable,
                                   GError         **error)
 {
-    g_return_val_if_fail (G_IS_INPUT_STREAM (input_stream), NULL);
-    g_return_val_if_fail (base_file == NULL || G_IS_FILE (base_file), NULL);
-    g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), NULL);
-    g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-
     return rsvg_rust_handle_new_from_stream_sync (input_stream,
                                                   base_file,
                                                   flags,
@@ -635,12 +616,7 @@ rsvg_handle_new_from_stream_sync (GInputStream    *input_stream,
 gboolean
 rsvg_handle_write (RsvgHandle *handle, const guchar *buf, gsize count, GError **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-    g_return_val_if_fail ((buf != NULL && count != 0) || (count == 0), FALSE);
-
-    rsvg_rust_handle_write (handle, buf, count);
-    return TRUE;
+    return rsvg_rust_handle_write (handle, buf, count, error);
 }
 
 /**
@@ -662,9 +638,6 @@ rsvg_handle_write (RsvgHandle *handle, const guchar *buf, gsize count, GError **
 gboolean
 rsvg_handle_close (RsvgHandle *handle, GError **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_close(handle, error);
 }
 
@@ -699,11 +672,6 @@ rsvg_handle_read_stream_sync (RsvgHandle   *handle,
                               GCancellable *cancellable,
                               GError      **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (G_IS_INPUT_STREAM (stream), FALSE);
-    g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_read_stream_sync (handle,
                                               stream,
                                               cancellable,
@@ -725,9 +693,6 @@ rsvg_handle_read_stream_sync (RsvgHandle   *handle,
 void
 rsvg_handle_set_base_uri (RsvgHandle *handle, const char *base_uri)
 {
-    g_return_if_fail (RSVG_IS_HANDLE (handle));
-    g_return_if_fail (base_uri != NULL);
-
     rsvg_rust_handle_set_base_url (handle, base_uri);
 }
 
@@ -747,9 +712,6 @@ void
 rsvg_handle_set_base_gfile (RsvgHandle *handle,
                             GFile      *base_file)
 {
-    g_return_if_fail (RSVG_IS_HANDLE (handle));
-    g_return_if_fail (G_IS_FILE (base_file));
-
     rsvg_rust_handle_set_base_gfile (handle, base_file);
 }
 
@@ -765,8 +727,6 @@ rsvg_handle_set_base_gfile (RsvgHandle *handle,
 const char *
 rsvg_handle_get_base_uri (RsvgHandle *handle)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), NULL);
-
     return rsvg_rust_handle_get_base_url (handle);
 }
 
@@ -774,7 +734,7 @@ rsvg_handle_get_base_uri (RsvgHandle *handle)
  * rsvg_handle_set_stylesheet:
  * @handle: A #RsvgHandle.
  * @css: (array length=css_len): String with CSS data; must be valid UTF-8.
- * @css_len: Length of the @css string in bytes.
+ * @css_len: Length of the @css data in bytes.
  * @error: (optional): return location for errors.
  *
  * Sets a CSS stylesheet to use for an SVG document.
@@ -792,15 +752,11 @@ rsvg_handle_get_base_uri (RsvgHandle *handle)
  * Since: 2.48
  */
 gboolean
-rsvg_handle_set_stylesheet (RsvgHandle  *handle,
-                            const char  *css,
-                            gsize        css_len,
-                            GError     **error)
+rsvg_handle_set_stylesheet (RsvgHandle   *handle,
+                            const guint8 *css,
+                            gsize         css_len,
+                            GError      **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail ((css != NULL && css_len >= 0) || (css == NULL && css_len == 0), FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_set_stylesheet (handle, css, css_len, error);
 }
 
@@ -892,9 +848,6 @@ rsvg_handle_get_desc (RsvgHandle *handle)
 gboolean
 rsvg_handle_render_cairo_sub (RsvgHandle *handle, cairo_t *cr, const char *id)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (cr != NULL, FALSE);
-
     return rsvg_rust_handle_render_cairo_sub (handle, cr, id);
 }
 
@@ -941,9 +894,6 @@ rsvg_handle_render_cairo (RsvgHandle *handle, cairo_t *cr)
 void
 rsvg_handle_get_dimensions (RsvgHandle *handle, RsvgDimensionData *dimension_data)
 {
-    g_return_if_fail (RSVG_IS_HANDLE (handle));
-    g_return_if_fail (dimension_data != NULL);
-
     rsvg_rust_handle_get_dimensions (handle, dimension_data);
 }
 
@@ -974,9 +924,6 @@ rsvg_handle_get_dimensions_sub (RsvgHandle *handle,
                                 RsvgDimensionData *dimension_data,
                                 const char *id)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (dimension_data, FALSE);
-
     return rsvg_rust_handle_get_dimensions_sub (handle, dimension_data, id);
 }
 
@@ -1007,9 +954,6 @@ rsvg_handle_get_position_sub (RsvgHandle *handle,
                               RsvgPositionData *position_data,
                               const char *id)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (position_data != NULL, FALSE);
-
     return rsvg_rust_handle_get_position_sub (handle, position_data, id);
 }
 
@@ -1033,8 +977,6 @@ rsvg_handle_get_position_sub (RsvgHandle *handle,
 gboolean
 rsvg_handle_has_sub (RsvgHandle *handle, const char *id)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-
     return rsvg_rust_handle_has_sub (handle, id);
 }
 
@@ -1071,8 +1013,6 @@ rsvg_handle_has_sub (RsvgHandle *handle, const char *id)
 GdkPixbuf *
 rsvg_handle_get_pixbuf_sub (RsvgHandle *handle, const char *id)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), NULL);
-
     return rsvg_rust_handle_get_pixbuf_sub (handle, id);
 }
 
@@ -1135,10 +1075,7 @@ rsvg_handle_set_dpi (RsvgHandle *handle, double dpi)
 void
 rsvg_handle_set_dpi_x_y (RsvgHandle *handle, double dpi_x, double dpi_y)
 {
-    g_return_if_fail (RSVG_IS_HANDLE (handle));
-
-    rsvg_rust_handle_set_dpi_x (handle, dpi_x);
-    rsvg_rust_handle_set_dpi_y (handle, dpi_y);
+    rsvg_rust_handle_set_dpi_x_y (handle, dpi_x, dpi_y);
 }
 
 /**
@@ -1204,8 +1141,6 @@ rsvg_handle_set_size_callback (RsvgHandle *handle,
                                gpointer user_data,
                                GDestroyNotify user_data_destroy)
 {
-    g_return_if_fail (RSVG_IS_HANDLE (handle));
-
     rsvg_rust_handle_set_size_callback (handle,
                                         size_func,
                                         user_data,
@@ -1265,8 +1200,6 @@ rsvg_handle_get_intrinsic_dimensions (RsvgHandle *handle,
                                       gboolean   *out_has_viewbox,
                                       RsvgRectangle *out_viewbox)
 {
-    g_return_if_fail (RSVG_IS_HANDLE (handle));
-
     rsvg_rust_handle_get_intrinsic_dimensions (handle,
                                                out_has_width,
                                                out_width,
@@ -1304,11 +1237,6 @@ rsvg_handle_render_document (RsvgHandle           *handle,
                              const RsvgRectangle  *viewport,
                              GError              **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (cr != NULL, FALSE);
-    g_return_val_if_fail (viewport != NULL, FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_render_document (handle, cr, viewport, error);
 }
 
@@ -1362,10 +1290,6 @@ rsvg_handle_get_geometry_for_layer (RsvgHandle     *handle,
                                     RsvgRectangle  *out_logical_rect,
                                     GError        **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (viewport != NULL, FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_get_geometry_for_layer (handle,
                                                     id,
                                                     viewport,
@@ -1415,11 +1339,6 @@ rsvg_handle_render_layer (RsvgHandle           *handle,
                           const RsvgRectangle  *viewport,
                           GError              **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (cr != NULL, FALSE);
-    g_return_val_if_fail (viewport != NULL, FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_render_layer (handle, cr, id, viewport, error);
 }
 
@@ -1477,9 +1396,6 @@ rsvg_handle_get_geometry_for_element (RsvgHandle     *handle,
                                       RsvgRectangle  *out_logical_rect,
                                       GError        **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_get_geometry_for_element (handle,
                                                       id,
                                                       out_ink_rect,
@@ -1529,11 +1445,6 @@ rsvg_handle_render_element (RsvgHandle           *handle,
                             const RsvgRectangle  *element_viewport,
                             GError              **error)
 {
-    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
-    g_return_val_if_fail (cr != NULL, FALSE);
-    g_return_val_if_fail (element_viewport != NULL, FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
     return rsvg_rust_handle_render_element (handle, cr, id, element_viewport, error);
 }
 
@@ -1548,8 +1459,6 @@ rsvg_handle_render_element (RsvgHandle           *handle,
 void
 rsvg_handle_internal_set_testing (RsvgHandle *handle, gboolean testing)
 {
-    g_return_if_fail (RSVG_IS_HANDLE (handle));
-
     rsvg_rust_handle_set_testing (handle, testing);
 }
 
